@@ -1120,10 +1120,11 @@ mod tests {
     use super::cargo_test_fuzz as cargo;
     use anyhow::Result;
 
+    #[allow(unknown_lints)]
+    #[allow(nonreentrant_function_in_test)]
     #[test]
     fn build_no_instrumentation_with_target() {
         cargo_test_fuzz(&[
-            "--no-default-features",
             "--features",
             &("test-fuzz/".to_owned() + test_fuzz::serde_format().as_feature()),
             "--no-run",
